# ##### BEGIN GPL LICENSE BLOCK #####
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; either version 2
#  of the License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software Foundation,
#  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# ##### END GPL LICENSE BLOCK #####

bl_info = {
    "name": "Quick Pipe",
    "author": "floatvoid (Jeremy Mitchell), Pavel Geraskin, Cebbi, Alexander Belyakov, KE",
    "version": (2, 4, 3),
    "blender": (4, 0, 0),
    "location": "View3D > Edit Mode >, Edge Menu (Ctrl + E)",
    "description": "Quickly converts an edge selection to an extruded curve.",
    "warning": "",
    "wiki_url": "https://blenderartists.org/t/quick-pipe-for-blender-2-8/1163126",
    "category": "Mesh"}

# Updated for 4.0 - KE

import bpy
from .operators.quick_pipe import jmPipeTool
from .operators.match_pipe_width import MatchPipeWidth
from .preferences import QuickPipePreferences


classes = (
    jmPipeTool,
    MatchPipeWidth,
    QuickPipePreferences,
)


def menu_func(self, context):
    self.layout.operator_context = "INVOKE_DEFAULT"
    self.layout.operator(jmPipeTool.bl_idname, text="Quick Pipe")


def register():
    for cls in classes:
        bpy.utils.register_class(cls)
    bpy.types.VIEW3D_MT_edit_mesh_edges.append(menu_func)  # Edge Menu(CTRL+E)
    bpy.types.Scene.quick_pipe_fill_caps = bpy.props.BoolProperty()


def unregister():
    for cls in classes:
        bpy.utils.unregister_class(cls)
    bpy.types.VIEW3D_MT_edit_mesh_edges.remove(menu_func)
    del bpy.types.Scene.quick_pipe_fill_caps


if __name__ == "__main__":
    register()
